# Intx
An extension to the base integer type of python. Has features like iterating over integers (including: appending, inserting, popping) and handy stuff like isPrime() etc.

## Installing
You can get the package by doing `pip install intx` or `python3 -m pip install intx`

## Use cases
```python
x = intx(12345)
for i in x:
  print(x)
>> 1
>> 2
>> 3
>> 4
>> 5

x.isEven()
>> False
...
```

## Pypi page
[Link](https://pypi.org/project/intx/) to the Pypi page.
